@@ -9,7 +9,7 @@ RawKIT class is adapted from Denis Engemann et al.'s mne_bti2fiff.py.
 #
 # License: BSD (3-clause)
 
-from collections import defaultdict
+from collections import defaultdict, OrderedDict
 from math import sin, cos
 from os import SEEK_CUR, path as op
 from struct import unpack
@@ -33,7 +33,13 @@ from ...event import read_events
 from .._digitization import _set_dig_kit
 
 
-def _call_digitization(info, mrk, elp, hsp):
+def _call_digitization(info, mrk, elp, hsp, kit_info):
+    # Use values from kit_info only if all others are None
+    if mrk is None and elp is None and hsp is None:
+        mrk = kit_info.get('mrk', None)
+        elp = kit_info.get('elp', None)
+        hsp = kit_info.get('hsp', None)
+
     # prepare mrk
     if isinstance(mrk, list):
         mrk = [read_mrk(marker) if isinstance(marker, str)
@@ -42,7 +48,8 @@ def _call_digitization(info, mrk, elp, hsp):
 
     # setup digitization
     if mrk is not None and elp is not None and hsp is not None:
-        dig_points, dev_head_t = _set_dig_kit(mrk, elp, hsp)
+        dig_points, dev_head_t = _set_dig_kit(
+            mrk, elp, hsp, kit_info['eeg_dig'])
         info['dig'] = dig_points
         info['dev_head_t'] = dev_head_t
     elif mrk is not None or elp is not None or hsp is not None:
@@ -100,6 +107,7 @@ class RawKIT(BaseRaw):
     allow_unknown_format : bool
         Force reading old data that is not officially supported. Alternatively,
         read and re-save the data with the KIT MEG Laboratory application.
+    %(standardize_names)s
     %(verbose)s
 
     Notes
@@ -117,12 +125,14 @@ class RawKIT(BaseRaw):
     @verbose
     def __init__(self, input_fname, mrk=None, elp=None, hsp=None, stim='>',
                  slope='-', stimthresh=1, preload=False, stim_code='binary',
-                 allow_unknown_format=False, verbose=None):  # noqa: D102
+                 allow_unknown_format=False, standardize_names=None,
+                 verbose=None):  # noqa: D102
         logger.info('Extracting SQD Parameters from %s...' % input_fname)
         input_fname = op.abspath(input_fname)
         self.preload = False
         logger.info('Creating Raw.info structure...')
-        info, kit_info = get_kit_info(input_fname, allow_unknown_format)
+        info, kit_info = get_kit_info(
+            input_fname, allow_unknown_format, standardize_names)
         kit_info['slope'] = slope
         kit_info['stimthresh'] = stimthresh
         if kit_info['acq_type'] != KIT.CONTINUOUS:
@@ -136,13 +146,8 @@ class RawKIT(BaseRaw):
         super(RawKIT, self).__init__(
             info, preload, last_samps=last_samps, filenames=[input_fname],
             raw_extras=self._raw_extras, verbose=verbose)
-
-        self.info = _call_digitization(info=self.info,
-                                       mrk=mrk,
-                                       elp=elp,
-                                       hsp=hsp,
-                                       )
-
+        self.info = _call_digitization(
+            info=self.info, mrk=mrk, elp=elp, hsp=hsp, kit_info=kit_info)
         logger.info('Ready.')
 
     def read_stim_ch(self, buffer_size=1e5):
@@ -164,7 +169,7 @@ class RawKIT(BaseRaw):
 
         pick = pick_types(self.info, meg=False, ref_meg=False,
                           stim=True, exclude=[])
-        stim_ch = np.empty((1, stop), dtype=np.int)
+        stim_ch = np.empty((1, stop), dtype=np.int64)
         for b_start in range(start, stop, buffer_size):
             b_stop = b_start + buffer_size
             x = self[pick, b_start:b_stop][0]
@@ -221,9 +226,10 @@ class RawKIT(BaseRaw):
             nchan = self._raw_extras[0]['nchan'] + 1
             info['chs'].append(dict(
                 cal=KIT.CALIB_FACTOR, logno=nchan, scanno=nchan, range=1.0,
-                unit=FIFF.FIFF_UNIT_NONE, unit_mul=0, ch_name='STI 014',
+                unit=FIFF.FIFF_UNIT_NONE, unit_mul=FIFF.FIFF_UNITM_NONE,
+                ch_name='STI 014',
                 coil_type=FIFF.FIFFV_COIL_NONE, loc=np.full(12, np.nan),
-                kind=FIFF.FIFFV_STIM_CH))
+                kind=FIFF.FIFFV_STIM_CH, coord_frame=FIFF.FIFFV_COORD_UNKNOWN))
             info._update_redundant()
 
         self._raw_extras[0]['stim'] = stim
@@ -231,24 +237,23 @@ class RawKIT(BaseRaw):
 
     def _read_segment_file(self, data, idx, fi, start, stop, cals, mult):
         """Read a chunk of raw data."""
-        nchan = self._raw_extras[fi]['nchan']
+        sqd = self._raw_extras[fi]
+        nchan = sqd['nchan']
         data_left = (stop - start) * nchan
-        conv_factor = self._raw_extras[fi]['conv_factor']
+        conv_factor = sqd['conv_factor']
 
-        n_bytes = 2
+        n_bytes = sqd['dtype'].itemsize
+        assert n_bytes in (2, 4)
         # Read up to 100 MB of data at a time.
         blk_size = min(data_left, (100000000 // n_bytes // nchan) * nchan)
         with open(self._filenames[fi], 'rb', buffering=0) as fid:
             # extract data
-            fid.seek(144)
-            # data offset info
-            data_offset = unpack('i', fid.read(KIT.INT))[0]
-            pointer = start * nchan * KIT.SHORT
-            fid.seek(data_offset + pointer)
-            stim = self._raw_extras[fi]['stim']
+            pointer = start * nchan * n_bytes
+            fid.seek(sqd['dirs'][KIT.DIR_INDEX_RAW_DATA]['offset'] + pointer)
+            stim = sqd['stim']
             for blk_start in np.arange(0, data_left, blk_size) // nchan:
                 blk_size = min(blk_size, data_left - blk_start * nchan)
-                block = np.fromfile(fid, dtype='h', count=blk_size)
+                block = np.fromfile(fid, dtype=sqd['dtype'], count=blk_size)
                 block = block.reshape(nchan, -1, order='F').astype(float)
                 blk_stop = blk_start + block.shape[1]
                 data_view = data[:, blk_start:blk_stop]
@@ -256,14 +261,12 @@ class RawKIT(BaseRaw):
 
                 # Create a synthetic stim channel
                 if stim is not None:
-                    params = self._raw_extras[fi]
-                    stim_ch = _make_stim_channel(block[stim, :],
-                                                 params['slope'],
-                                                 params['stimthresh'],
-                                                 params['stim_code'], stim)
+                    stim_ch = _make_stim_channel(
+                        block[stim, :], sqd['slope'], sqd['stimthresh'],
+                        sqd['stim_code'], stim)
                     block = np.vstack((block, stim_ch))
 
-                _mult_cal_one(data_view, block, idx, None, mult)
+                _mult_cal_one(data_view, block, idx, cals, mult)
         # cals are all unity, so can be ignored
 
 
@@ -359,6 +362,7 @@ class EpochsKIT(BaseEpochs):
     allow_unknown_format : bool
         Force reading old data that is not officially supported. Alternatively,
         read and re-save the data with the KIT MEG Laboratory application.
+    %(standardize_names)s
     %(verbose)s
 
     Notes
@@ -377,14 +381,16 @@ class EpochsKIT(BaseEpochs):
     def __init__(self, input_fname, events, event_id=None, tmin=0,
                  baseline=None, reject=None, flat=None, reject_tmin=None,
                  reject_tmax=None, mrk=None, elp=None, hsp=None,
-                 allow_unknown_format=False, verbose=None):  # noqa: D102
+                 allow_unknown_format=False, standardize_names=None,
+                 verbose=None):  # noqa: D102
 
         if isinstance(events, str):
             events = read_events(events)
 
         logger.info('Extracting KIT Parameters from %s...' % input_fname)
         input_fname = op.abspath(input_fname)
-        self.info, kit_info = get_kit_info(input_fname, allow_unknown_format)
+        self.info, kit_info = get_kit_info(
+            input_fname, allow_unknown_format, standardize_names)
         kit_info.update(filename=input_fname)
         self._raw_extras = [kit_info]
         self._filenames = []
@@ -393,7 +399,6 @@ class EpochsKIT(BaseEpochs):
 
         if self._raw_extras[0]['acq_type'] == KIT.EPOCHS:
             self._raw_extras[0]['data_length'] = KIT.INT
-            self._raw_extras[0]['dtype'] = 'h'
         else:
             raise TypeError('SQD file contains raw data, not epochs or '
                             'average. Wrong reader.')
@@ -415,14 +420,8 @@ class EpochsKIT(BaseEpochs):
             self.info, data, events, event_id, tmin, tmax, baseline,
             reject=reject, flat=flat, reject_tmin=reject_tmin,
             reject_tmax=reject_tmax, filename=input_fname, verbose=verbose)
-
-        # XXX: This should be unified with kitraw
-        self.info = _call_digitization(info=self.info,
-                                       mrk=mrk,
-                                       elp=elp,
-                                       hsp=hsp,
-                                       )
-
+        self.info = _call_digitization(
+            info=self.info, mrk=mrk, elp=elp, hsp=hsp, kit_info=kit_info)
         logger.info('Ready.')
 
     def _read_kit_data(self):
@@ -444,11 +443,8 @@ class EpochsKIT(BaseEpochs):
         nchan = info['nchan']
 
         with open(filename, 'rb', buffering=0) as fid:
-            fid.seek(144)
-            # data offset info
-            data_offset = unpack('i', fid.read(KIT.INT))[0]
+            fid.seek(info['dirs'][KIT.DIR_INDEX_RAW_DATA]['offset'])
             count = n_samples * nchan
-            fid.seek(data_offset)
             data = np.fromfile(fid, dtype=dtype, count=count)
         data = data.reshape((n_samples, nchan)).T
         data = data * info['conv_factor']
@@ -458,8 +454,17 @@ class EpochsKIT(BaseEpochs):
         return data
 
 
-def get_kit_info(rawfile, allow_unknown_format):
-    """Extract all the information from the sqd file.
+def _read_dir(fid):
+    return dict(offset=np.fromfile(fid, np.uint32, 1)[0],
+                size=np.fromfile(fid, np.int32, 1)[0],
+                max_count=np.fromfile(fid, np.int32, 1)[0],
+                count=np.fromfile(fid, np.int32, 1)[0])
+
+
+@verbose
+def get_kit_info(rawfile, allow_unknown_format, standardize_names=None,
+                 verbose=None):
+    """Extract all the information from the sqd/con file.
 
     Parameters
     ----------
@@ -468,6 +473,8 @@ def get_kit_info(rawfile, allow_unknown_format):
     allow_unknown_format : bool
         Force reading old data that is not officially supported. Alternatively,
         read and re-save the data with the KIT MEG Laboratory application.
+    %(standardize_names)s
+    %(verbose)s
 
     Returns
     -------
@@ -479,10 +486,19 @@ def get_kit_info(rawfile, allow_unknown_format):
     sqd = dict()
     sqd['rawfile'] = rawfile
     unsupported_format = False
+    sqd['dirs'] = dirs = list()
     with open(rawfile, 'rb', buffering=0) as fid:  # buffering=0 for np bug
-        fid.seek(16)
-        basic_offset = unpack('i', fid.read(KIT.INT))[0]
-        fid.seek(basic_offset)
+        #
+        # directories (0)
+        #
+        dirs.append(_read_dir(fid))
+        dirs.extend(_read_dir(fid) for _ in range(dirs[0]['count'] - 1))
+        assert len(dirs) == dirs[KIT.DIR_INDEX_DIR]['count']
+
+        #
+        # system (1)
+        #
+        fid.seek(dirs[KIT.DIR_INDEX_SYSTEM]['offset'])
         # check file format version
         version, revision = unpack('2i', fid.read(2 * KIT.INT))
         if version < 2 or (version == 2 and revision < 3):
@@ -527,8 +543,9 @@ def get_kit_info(rawfile, allow_unknown_format):
         model_name = model_name.replace('\x00', '')
         model_name = model_name.strip().replace('\n', '/')
 
+        full_version = f'V{version:d}R{revision:03d}'
         logger.debug("SQD file basic information:")
-        logger.debug("Meg160 version = V%iR%03i", version, revision)
+        logger.debug("Meg160 version = %s", full_version)
         logger.debug("System ID      = %i", sysid)
         logger.debug("System name    = %s", system_name)
         logger.debug("Model name     = %s", model_name)
@@ -541,6 +558,10 @@ def get_kit_info(rawfile, allow_unknown_format):
         logger.debug("ADC range      = +/-%s[V]", adc_range / 2.)
         logger.debug("ADC allocate   = %i[bit]", adc_allocated)
         logger.debug("ADC bit        = %i[bit]", adc_stored)
+        # MGH description: 'acquisition (megacq) VectorView system at NMR-MGH'
+        description = \
+            f'{system_name} ({sysid}) {full_version} {model_name}'
+        sqd['dtype'] = np.dtype(getattr(np, f'int{adc_allocated}'))
 
         # check that we can read this file
         if fll_type not in KIT.FLL_SETTINGS:
@@ -554,10 +575,13 @@ def get_kit_info(rawfile, allow_unknown_format):
                  % (system_name, model_name, sysid, fll_type, use_fll_type))
             fll_type = use_fll_type
 
-        # channel information
-        fid.seek(64)
-        chan_offset, chan_size = unpack('2i', fid.read(2 * KIT.INT))
+        #
+        # channel information (4)
+        #
+        chan_dir = dirs[KIT.DIR_INDEX_CHANNELS]
+        chan_offset, chan_size = chan_dir['offset'], chan_dir['size']
         sqd['channels'] = channels = []
+        exg_gains = list()
         for i in range(channel_count):
             fid.seek(chan_offset + chan_size * i)
             channel_type, = unpack('i', fid.read(KIT.INT))
@@ -575,37 +599,48 @@ def get_kit_info(rawfile, allow_unknown_format):
                     'type': channel_type,
                     # (x, y, z, theta, phi) for all MEG channels. Some channel
                     # types have additional information which we're not using.
-                    'loc': np.fromfile(fid, dtype='d', count=5)
+                    'loc': np.fromfile(fid, dtype='d', count=5),
                 })
+                if channel_type in KIT.CHANNEL_NAME_NCHAR:
+                    fid.seek(16, SEEK_CUR)  # misc fields
+                    channels[-1]['name'] = _read_name(fid, channel_type)
             elif channel_type in KIT.CHANNELS_MISC:
                 channel_no, = unpack('i', fid.read(KIT.INT))
-                # name, = unpack('64s', fid.read(64))
-                fid.seek(64, 1)
+                fid.seek(4, SEEK_CUR)
+                name = _read_name(fid, channel_type)
                 channels.append({
                     'type': channel_type,
                     'no': channel_no,
+                    'name': name,
                 })
+                if channel_type in (KIT.CHANNEL_EEG, KIT.CHANNEL_ECG):
+                    offset = 6 if channel_type == KIT.CHANNEL_EEG else 8
+                    fid.seek(offset, SEEK_CUR)
+                    exg_gains.append(np.fromfile(fid, 'd', 1)[0])
             elif channel_type == KIT.CHANNEL_NULL:
                 channels.append({'type': channel_type})
             else:
                 raise IOError("Unknown KIT channel type: %i" % channel_type)
+        exg_gains = np.array(exg_gains)
+
+        #
+        # Channel sensitivity information: (5)
+        #
 
-        # Channel sensitivity information:
         # only sensor channels requires gain. the additional misc channels
         # (trigger channels, audio and voice channels) are passed
         # through unaffected
-        fid.seek(80)
-        sensitivity_offset, = unpack('i', fid.read(KIT.INT))
-        fid.seek(sensitivity_offset)
+        fid.seek(dirs[KIT.DIR_INDEX_CALIBRATION]['offset'])
         # (offset [Volt], gain [Tesla/Volt]) for each channel
         sensitivity = np.fromfile(fid, dtype='d', count=channel_count * 2)
         sensitivity.shape = (channel_count, 2)
         channel_offset, channel_gain = sensitivity.T
+        assert (channel_offset == 0).all()  # otherwise we have a problem
 
-        # amplifier gain
-        fid.seek(112)
-        amp_offset = unpack('i', fid.read(KIT.INT))[0]
-        fid.seek(amp_offset)
+        #
+        # amplifier gain (7)
+        #
+        fid.seek(dirs[KIT.DIR_INDEX_AMP_FILTER]['offset'])
         amp_data = unpack('i', fid.read(KIT.INT))[0]
         if fll_type >= 100:  # Kapper Type
             # gain:             mask           bit
@@ -631,15 +666,15 @@ def get_kit_info(rawfile, allow_unknown_format):
         sqd['lowpass'] = KIT.LPFS[lpf_options][lpf]
         sqd['notch'] = KIT.BEFS[bef_options][bef]
 
-        # Acquisition Parameters
-        fid.seek(128)
-        acqcond_offset, = unpack('i', fid.read(KIT.INT))
-        fid.seek(acqcond_offset)
+        #
+        # Acquisition Parameters (8)
+        #
+        fid.seek(dirs[KIT.DIR_INDEX_ACQ_COND]['offset'])
         sqd['acq_type'], = acq_type, = unpack('i', fid.read(KIT.INT))
         sqd['sfreq'], = unpack('d', fid.read(KIT.DOUBLE))
         if acq_type == KIT.CONTINUOUS:
             # samples_count, = unpack('i', fid.read(KIT.INT))
-            fid.seek(KIT.INT, 1)
+            fid.seek(KIT.INT, SEEK_CUR)
             sqd['n_samples'], = unpack('i', fid.read(KIT.INT))
         elif acq_type == KIT.EVOKED or acq_type == KIT.EPOCHS:
             sqd['frame_length'], = unpack('i', fid.read(KIT.INT))
@@ -654,6 +689,65 @@ def get_kit_info(rawfile, allow_unknown_format):
             raise IOError("Invalid acquisition type: %i. Your file is neither "
                           "continuous nor epoched data." % (acq_type,))
 
+        #
+        # digitization information (12 and 26)
+        #
+        dig_dir = dirs[KIT.DIR_INDEX_DIG_POINTS]
+        cor_dir = dirs[KIT.DIR_INDEX_COREG]
+        dig = dict()
+        hsp = list()
+        if dig_dir['count'] > 0 and cor_dir['count'] > 0:
+            # directories (0)
+            fid.seek(dig_dir['offset'])
+            for _ in range(dig_dir['count']):
+                name = _read_name(fid, n=8).strip()
+                # Sometimes there are mismatches (e.g., AFz vs AFZ) between
+                # the channel name and its digitized, name, so let's be case
+                # insensitive. It will also prevent collisions with HSP
+                name = name.lower()
+                rr = np.fromfile(fid, 'd', 3)
+                if name:
+                    assert name not in dig
+                    dig[name] = rr
+                else:
+                    hsp.append(rr)
+
+            # nasion, lpa, rpa, HPI in native space
+            elp = [dig.pop(key) for key in (
+                'fidnz', 'fidt9', 'fidt10',
+                'hpi_1', 'hpi_2', 'hpi_3', 'hpi_4')]
+            if 'hpi_5' in dig and dig['hpi_5'].any():
+                elp.append(dig.pop('hpi_5'))
+            elp = np.array(elp)
+            hsp = np.array(hsp, float).reshape(-1, 3)
+            assert elp.shape in ((7, 3), (8, 3))
+            # coregistration
+            fid.seek(cor_dir['offset'])
+            mrk = np.zeros((elp.shape[0] - 3, 3))
+            for _ in range(cor_dir['count']):
+                done = np.fromfile(fid, np.int32, 1)[0]
+                fid.seek(16 * KIT.DOUBLE +  # meg_to_mri
+                         16 * KIT.DOUBLE,  # mri_to_meg
+                         SEEK_CUR)
+                marker_count = np.fromfile(fid, np.int32, 1)[0]
+                if not done:
+                    continue
+                assert marker_count >= len(mrk)
+                for mi in range(len(mrk)):
+                    mri_type, meg_type, mri_done, meg_done = \
+                        np.fromfile(fid, np.int32, 4)
+                    assert meg_done
+                    fid.seek(3 * KIT.DOUBLE, SEEK_CUR)  # mri_pos
+                    mrk[mi] = np.fromfile(fid, 'd', 3)
+                fid.seek(256, SEEK_CUR)  # marker_file (char)
+            sqd.update(hsp=hsp, elp=elp, mrk=mrk)
+
+    all_names = set(ch.get('name', '') for ch in channels)
+    if standardize_names is None and all_names.difference({'', 'EEG'}):
+        standardize_names = True
+        warn('standardize_names defaults to True in 0.21 but will change '
+             'to False in 0.22', DeprecationWarning)
+
     # precompute conversion factor for reading data
     if unsupported_format:
         if sysid not in LEGACY_AMP_PARAMS:
@@ -661,24 +755,37 @@ def get_kit_info(rawfile, allow_unknown_format):
                           (sysid,))
         adc_range, adc_stored = LEGACY_AMP_PARAMS[sysid]
     is_meg = np.array([ch['type'] in KIT.CHANNELS_MEG for ch in channels])
-    ad_to_volt = adc_range / (2. ** adc_stored)
+    ad_to_volt = adc_range / (2 ** adc_stored)
     ad_to_tesla = ad_to_volt / amp_gain * channel_gain
     conv_factor = np.where(is_meg, ad_to_tesla, ad_to_volt)
+    # XXX this is a bit of a hack. Should probably do this more cleanly at
+    # some point... the 2 ** (adc_stored - 14) was emperically determined using
+    # the test files with known amplitudes. The conv_factors need to be
+    # replaced by these values otherwise we're off by a factor off 5000.0
+    # for the EEG data.
+    is_exg = [ch['type'] in (KIT.CHANNEL_EEG, KIT.CHANNEL_ECG)
+              for ch in channels]
+    exg_gains /= 2 ** (adc_stored - 14)
+    conv_factor[is_exg] = exg_gains
     sqd['conv_factor'] = conv_factor[:, np.newaxis]
 
     # Create raw.info dict for raw fif object with SQD data
     info = _empty_info(float(sqd['sfreq']))
     info.update(meas_date=_stamp_to_dt((create_time, 0)),
                 lowpass=sqd['lowpass'],
-                highpass=sqd['highpass'], kit_system_id=sysid)
+                highpass=sqd['highpass'], kit_system_id=sysid,
+                description=description)
 
     # Creates a list of dicts of meg channels for raw.info
     logger.info('Setting channel info structure...')
     info['chs'] = fiff_channels = []
     channel_index = defaultdict(lambda: 0)
+    sqd['eeg_dig'] = OrderedDict()
     for idx, ch in enumerate(channels, 1):
         if ch['type'] in KIT.CHANNELS_MEG:
-            ch_name = 'MEG %03d' % idx
+            ch_name = ch.get('name', '')
+            if ch_name == '' or standardize_names:
+                ch_name = 'MEG %03d' % idx
             # create three orthogonal vector
             # ch_angles[0]: theta, ch_angles[1]: phi
             theta, phi = np.radians(ch['loc'][3:])
@@ -687,7 +794,7 @@ def get_kit_info(rawfile, allow_unknown_format):
             z = cos(theta)
             vec_z = np.array([x, y, z])
             vec_z /= linalg.norm(vec_z)
-            vec_x = np.zeros(vec_z.size, dtype=np.float)
+            vec_x = np.zeros(vec_z.size, dtype=np.float64)
             if vec_z[1] < vec_z[2]:
                 if vec_z[0] < vec_z[1]:
                     vec_x[0] = 1.0
@@ -709,9 +816,15 @@ def get_kit_info(rawfile, allow_unknown_format):
             ch_type_label = KIT.CH_LABEL[ch['type']]
             channel_index[ch_type_label] += 1
             ch_type_index = channel_index[ch_type_label]
-            ch_name = '%s %03i' % (ch_type_label, ch_type_index)
+            ch_name = ch.get('name', '')
+            eeg_name = ch_name.lower()
+            # some files have all EEG labeled as EEG
+            if ch_name in ('', 'EEG') or standardize_names:
+                ch_name = '%s %03i' % (ch_type_label, ch_type_index)
             unit = FIFF.FIFF_UNIT_V
             loc = np.zeros(12)
+            if eeg_name and eeg_name in dig:
+                loc[:3] = sqd['eeg_dig'][eeg_name] = dig[eeg_name]
         fiff_channels.append(dict(
             cal=KIT.CALIB_FACTOR, logno=idx, scanno=idx, range=KIT.RANGE,
             unit=unit, unit_mul=KIT.UNIT_MUL, ch_name=ch_name,
@@ -722,11 +835,17 @@ def get_kit_info(rawfile, allow_unknown_format):
     return info, sqd
 
 
+def _read_name(fid, ch_type=None, n=None):
+    n = n if ch_type is None else KIT.CHANNEL_NAME_NCHAR[ch_type]
+    return fid.read(n).split(b'\x00')[0].decode('utf-8')
+
+
 @fill_doc
 def read_raw_kit(input_fname, mrk=None, elp=None, hsp=None, stim='>',
                  slope='-', stimthresh=1, preload=False, stim_code='binary',
-                 allow_unknown_format=False, verbose=None):
-    """Reader function for KIT conversion to FIF.
+                 allow_unknown_format=False, standardize_names=None,
+                 verbose=None):
+    """Reader function for Ricoh/KIT conversion to FIF.
 
     Parameters
     ----------
@@ -764,6 +883,7 @@ def read_raw_kit(input_fname, mrk=None, elp=None, hsp=None, stim='>',
     allow_unknown_format : bool
         Force reading old data that is not officially supported. Alternatively,
         read and re-save the data with the KIT MEG Laboratory application.
+    %(standardize_names)s
     %(verbose)s
 
     Returns
@@ -783,13 +903,15 @@ def read_raw_kit(input_fname, mrk=None, elp=None, hsp=None, stim='>',
     return RawKIT(input_fname=input_fname, mrk=mrk, elp=elp, hsp=hsp,
                   stim=stim, slope=slope, stimthresh=stimthresh,
                   preload=preload, stim_code=stim_code,
-                  allow_unknown_format=allow_unknown_format, verbose=verbose)
+                  allow_unknown_format=allow_unknown_format,
+                  standardize_names=standardize_names, verbose=verbose)
 
 
 @fill_doc
 def read_epochs_kit(input_fname, events, event_id=None, mrk=None, elp=None,
-                    hsp=None, allow_unknown_format=False, verbose=None):
-    """Reader function for KIT epochs files.
+                    hsp=None, allow_unknown_format=False,
+                    standardize_names=None, verbose=None):
+    """Reader function for Ricoh/KIT epochs files.
 
     Parameters
     ----------
@@ -821,6 +943,7 @@ def read_epochs_kit(input_fname, events, event_id=None, mrk=None, elp=None,
     allow_unknown_format : bool
         Force reading old data that is not officially supported. Alternatively,
         read and re-save the data with the KIT MEG Laboratory application.
+    %(standardize_names)s
     %(verbose)s
 
     Returns
@@ -835,5 +958,6 @@ def read_epochs_kit(input_fname, events, event_id=None, mrk=None, elp=None,
     epochs = EpochsKIT(input_fname=input_fname, events=events,
                        event_id=event_id, mrk=mrk, elp=elp, hsp=hsp,
                        allow_unknown_format=allow_unknown_format,
+                       standardize_names=standardize_names,
                        verbose=verbose)
     return epochs
