@@ -28,7 +28,7 @@ from .utils import (_toggle_options, _toggle_proj, _prepare_mne_browse,
                     _change_channel_group, _plot_annotations, _setup_butterfly,
                     _handle_decim, _setup_plot_projector, _check_cov,
                     _set_ax_label_style, _draw_vert_line, _simplify_float,
-                    _check_psd_fmax)
+                    _check_psd_fmax, _set_window_title)
 
 
 def _plot_update_raw_proj(params, bools):
@@ -97,12 +97,15 @@ def _pick_bad_channels(event, params):
     _plot_update_raw_proj(params, None)
 
 
+_RAW_CLIP_DEF = 3.
+
+
 @verbose
 def plot_raw(raw, events=None, duration=10.0, start=0.0, n_channels=20,
              bgcolor='w', color=None, bad_color=(0.8, 0.8, 0.8),
              event_color='cyan', scalings=None, remove_dc=True, order=None,
              show_options=False, title=None, show=True, block=False,
-             highpass=None, lowpass=None, filtorder=4, clipping=None,
+             highpass=None, lowpass=None, filtorder=4, clipping=_RAW_CLIP_DEF,
              show_first_samp=False, proj=True, group_by='type',
              butterfly=False, decim='auto', noise_cov=None, event_id=None,
              show_scrollbars=True, show_scalebars=True, verbose=None):
@@ -185,11 +188,17 @@ def plot_raw(raw, events=None, duration=10.0, start=0.0, n_channels=20,
 
         .. versionchanged:: 0.18
            Support for ``filtorder=0`` to use FIR filtering.
-    clipping : str | None
+    clipping : str | float | None
         If None, channels are allowed to exceed their designated bounds in
         the plot. If "clamp", then values are clamped to the appropriate
         range for display, creating step-like artifacts. If "transparent",
         then excessive values are not shown, creating gaps in the traces.
+        If float, clipping occurs for values beyond the ``clipping`` multiple
+        of their dedicated range, so ``clipping=1.`` is an alias for
+        ``clipping='transparent'``.
+
+        .. versionchanged:: 0.21
+           Support for float, and default changed from None to 1.5.
     show_first_samp : bool
         If True, show time axis relative to the ``raw.first_samp``.
     proj : bool
@@ -278,7 +287,13 @@ def plot_raw(raw, events=None, duration=10.0, start=0.0, n_channels=20,
                                  duration=duration)
     _validate_type(raw, BaseRaw, 'raw', 'Raw')
     n_channels = min(len(raw.info['chs']), n_channels)
-    _check_option('clipping', clipping, [None, 'clamp', 'transparent'])
+    _validate_type(clipping, (None, 'numeric', str), 'clipping')
+    if isinstance(clipping, str):
+        _check_option('clipping', clipping, ['clamp', 'transparent'],
+                      extra='when a string')
+        clipping = 1. if clipping == 'transparent' else clipping
+    elif clipping is not None:
+        clipping = float(clipping)
     duration = min(raw.times[-1], float(duration))
 
     # figure out the IIR filtering parameters
@@ -335,7 +350,7 @@ def plot_raw(raw, events=None, duration=10.0, start=0.0, n_channels=20,
     for t in ['grad', 'mag']:
         inds += [pick_types(info, meg=t, ref_meg=False, exclude=[])]
         types += [t] * len(inds[-1])
-    for t in ['hbo', 'hbr', 'fnirs_raw', 'fnirs_od']:
+    for t in ['hbo', 'hbr', 'fnirs_cw_amplitude', 'fnirs_od']:
         inds += [pick_types(info, meg=False, ref_meg=False, fnirs=t,
                             exclude=[])]
         types += [t] * len(inds[-1])
@@ -589,11 +604,7 @@ def plot_raw_psd(raw, fmin=0, fmax=np.inf, tmin=None, tmax=None, proj=False,
     n_overlap : int
         The number of points of overlap between blocks. The default value
         is 0 (no overlap).
-    reject_by_annotation : bool
-        Whether to omit bad segments from the data while computing the
-        PSD. If True, annotated segments with a description that starts
-        with 'bad' are omitted. Has no effect if ``inst`` is an Epochs or
-        Evoked object. Defaults to True.
+    %(reject_by_annotation_raw)s
     %(plot_psd_picks_good_data)s
     ax : instance of Axes | None
         Axes to plot into. If None, axes will be created.
@@ -649,7 +660,7 @@ def _prepare_mne_browse_raw(params, title, bgcolor, color, bad_color, inds,
 
     figsize = _get_figsize_from_config()
     params['fig'] = figure_nobar(facecolor=bgcolor, figsize=figsize)
-    params['fig'].canvas.set_window_title(title or "Raw")
+    _set_window_title(params['fig'], title or "Raw")
     # most of the axes setup is done in _prepare_mne_browse
     _prepare_mne_browse(params, xlabel='Time (s)')
     ax = params['ax']
@@ -662,10 +673,11 @@ def _prepare_mne_browse_raw(params, title, bgcolor, color, bad_color, inds,
 
     if 'fig_selection' in params:
         selections = params['selections']
-        labels = [l._text for l in params['fig_selection'].radio.labels]
+        labels = [
+            label._text for label in params['fig_selection'].radio.labels]
         # Flatten the selections dict to a list.
-        cis = [item for sublist in [selections[l] for l in labels] for item
-               in sublist]
+        sels = [selections[label] for label in labels]
+        cis = [item for sublist in sels for item in sublist]
 
         for idx, ci in enumerate(cis):
             this_color = (bad_color if info['ch_names'][ci] in
@@ -701,8 +713,6 @@ def _prepare_mne_browse_raw(params, title, bgcolor, color, bad_color, inds,
     ax_hscroll.set_xlim(params['first_time'], params['first_time'] +
                         params['n_times'] / float(info['sfreq']))
 
-    ax_vscroll.set_title('Ch.')
-
     vertline_color = (0., 0.75, 0.)
     params['ax_vertline'] = ax.axvline(0, color=vertline_color, zorder=4)
     params['ax_vertline'].ch_name = ''
@@ -719,7 +729,9 @@ def _prepare_mne_browse_raw(params, title, bgcolor, color, bad_color, inds,
 
     params['lines'] = [ax.plot([np.nan], antialiased=True, linewidth=0.5)[0]
                        for _ in range(n_ch)]
-    ax.set_yticklabels(['X' * max([len(ch) for ch in info['ch_names']])])
+    ax.set_yticklabels(
+        ['X' * max([len(ch) for ch in info['ch_names']])] *
+        len(params['offsets']))
     params['fig_annotation'] = None
     params['fig_help'] = None
     params['segment_line'] = None
@@ -728,6 +740,7 @@ def _prepare_mne_browse_raw(params, title, bgcolor, color, bad_color, inds,
 def _plot_raw_traces(params, color, bad_color, event_lines=None,
                      event_color=None):
     """Plot raw traces."""
+    from matplotlib.patches import Rectangle
     lines = params['lines']
     info = params['info']
     inds = params['inds']
@@ -742,7 +755,6 @@ def _plot_raw_traces(params, color, bad_color, event_lines=None,
         offsets = params['offsets']
     params['bad_color'] = bad_color
     ax = params['ax']
-    labels = ax.yaxis.get_ticklabels()
     # Scalebars
     for bar in params.get('scalebars', {}).values():
         ax.lines.remove(bar)
@@ -751,6 +763,7 @@ def _plot_raw_traces(params, color, bad_color, event_lines=None,
     params['ax'].texts = []
     # do the plotting
     tick_list = list()
+    tick_colors = list()
     for ii in range(n_channels):
         ch_ind = ii + ch_start
         # let's be generous here and allow users to pass
@@ -768,12 +781,6 @@ def _plot_raw_traces(params, color, bad_color, event_lines=None,
             # apply user-supplied scale factor
             this_data = params['data'][inds[ch_ind]] * params['scale_factor']
 
-            # clip to range (if relevant)
-            if params['clipping'] == 'transparent':
-                this_data[np.abs(this_data) > 1] = np.nan
-            elif params['clipping'] == 'clamp':
-                np.clip(this_data, -1, 1, out=this_data)
-
             # set color
             this_color = bad_color if ch_name in info['bads'] else color
             if isinstance(this_color, dict):
@@ -785,6 +792,20 @@ def _plot_raw_traces(params, color, bad_color, event_lines=None,
                 this_decim = 1
             this_t = params['times'][::this_decim] + params['first_time']
 
+            # clip to range (if relevant)
+            if params['clipping'] == 'clamp':
+                np.clip(this_data, -1, 1, out=this_data)
+            elif params['clipping'] is not None:
+                l, w = this_t[0], this_t[-1] - this_t[0]
+                ylim = params['ax'].get_ylim()
+                b = offset - params['clipping']  # max(, ylim[0])
+                h = 2 * params['clipping']  # min(, ylim[1] - b)
+                assert ylim[1] <= ylim[0]  # inverted
+                b = max(b, ylim[1])
+                h = min(h, ylim[0] - b)
+                rect = Rectangle((l, b), w, h, transform=ax.transData)
+                lines[ii].set_clip_path(rect)
+
             # subtraction here gets correct orientation for flipped ylim
             lines[ii].set_ydata(offset - this_data[..., ::this_decim])
             lines[ii].set_xdata(this_t)
@@ -798,13 +819,11 @@ def _plot_raw_traces(params, color, bad_color, event_lines=None,
                         this_z = 2
                     elif params['types'][ii] == 'grad':
                         this_z = 3
-                for label in labels:
-                    label.set_color('black')
             else:
                 # set label color
                 this_color = (bad_color if ch_name in info['bads'] else
                               this_color)
-                labels[ii].set_color(this_color)
+                tick_colors.append(this_color)
             lines[ii].set_zorder(this_z)
             # add a scale bar
             if (params['show_scalebars'] and
@@ -901,8 +920,14 @@ def _plot_raw_traces(params, color, bad_color, event_lines=None,
                           params['times'][0] + params['first_time'] +
                           params['duration'], False)
     if not butterfly:
+        params['ax'].set_yticks(params['offsets'][:len(tick_list)])
         params['ax'].set_yticklabels(tick_list, rotation=0)
         _set_ax_label_style(params['ax'], params)
+    else:
+        tick_colors = ['k'] * len(params['ax'].get_yticks())
+    for tick_color, tick in zip(tick_colors,
+                                params['ax'].yaxis.get_ticklabels()):
+        tick.set_color(tick_color)
     if 'fig_selection' not in params:
         params['vsel_patch'].set_y(params['ch_start'])
     params['fig'].canvas.draw()
@@ -1006,7 +1031,7 @@ def _set_custom_selection(params):
     chs = params['fig_selection'].lasso.selection
     if len(chs) == 0:
         return
-    labels = [l._text for l in params['fig_selection'].radio.labels]
+    labels = [label._text for label in params['fig_selection'].radio.labels]
     inds = np.in1d(params['raw'].ch_names, chs)
     params['selections']['Custom'] = np.where(inds)[0]
 
@@ -1054,7 +1079,7 @@ def _setup_browser_selection(raw, kind, selector=True):
     if not selector:
         return order
     fig_selection = figure_nobar(figsize=(2, 6), dpi=80)
-    fig_selection.canvas.set_window_title('Selection')
+    _set_window_title(fig_selection, 'Selection')
     rax = plt.subplot2grid((6, 1), (2, 0), rowspan=4, colspan=1)
     topo_ax = plt.subplot2grid((6, 1), (0, 0), rowspan=2, colspan=1)
     keys = np.concatenate([keys, ['Custom']])
