@@ -317,13 +317,12 @@ aud_evoked.plot_topomap(times=[0., 0.08, 0.1, 0.12, 0.2], ch_type='eeg')
 
 ##############################################################################
 # Evoked objects can also be combined to show contrasts between conditions,
-# using the :func:`mne.combine_evoked` function. A simple difference can be
-# generated by negating one of the :class:`~mne.Evoked` objects passed into the
-# function. We'll then plot the difference wave at each sensor using
-# :meth:`~mne.Evoked.plot_topo`:
+# using the `mne.combine_evoked` function. A simple difference can be
+# generated by passing ``weights=[1, -1]``. We'll then plot the difference wave
+# at each sensor using `~mne.Evoked.plot_topo`:
 
-evoked_diff = mne.combine_evoked([aud_evoked, -vis_evoked], weights='equal')
-evoked_diff.pick_types('mag').plot_topo(color='r', legend=False)
+evoked_diff = mne.combine_evoked([aud_evoked, vis_evoked], weights=[1, -1])
+evoked_diff.pick_types(meg='mag').plot_topo(color='r', legend=False)
 
 ##############################################################################
 # Inverse modeling
